@@ -10,6 +10,10 @@ logger = logging.getLogger('mongonaut.forms')
 class DocumentListForm(forms.Form):
     """ The main document list form """
     mongo_id = forms.MultipleChoiceField(required=True, widget=forms.CheckboxSelectMultiple)
+    
+    def clean(self):
+        for field in self.fields:
+            print field
 
 
 class DocumentDetailForm(forms.Form):
@@ -34,6 +38,10 @@ def document_detail_form_factory(form, document_type, initial=False):
         logger.debug(field.__dict__)
         logging.debug('help')
         widget = get_widget(field)
+        if widget is None:
+            # ListField or EmbeddedDocumentField
+            continue
+            
         if isinstance(widget, forms.widgets.Select):
             form.fields[key] = forms.ChoiceField(
                 key, 
