@@ -5,6 +5,7 @@
 from datetime import datetime
 
 from django.conf import settings
+from django.contrib import messages
 from django.core.urlresolvers import reverse
 from django.forms import widgets
 from django.forms.widgets import DateTimeInput, CheckboxInput
@@ -23,7 +24,7 @@ from mongonaut.forms import document_detail_form_factory
 from mongonaut.mixins import MongonautViewMixin
 from mongonaut.utils import is_valid_object_id
 
-class IndexView(ListView, MongonautViewMixin):
+class IndexView(MongonautViewMixin, ListView):
 
     template_name = "mongonaut/index.html"
     queryset = []
@@ -31,12 +32,12 @@ class IndexView(ListView, MongonautViewMixin):
     def get_queryset(self):
         return self.get_mongoadmins()
 
-class AppListView(ListView, MongonautViewMixin):
+class AppListView(MongonautViewMixin, ListView):
     """ :args: <app_label> """
 
     template_name = "mongonaut/app_list.html"
 
-class DocumentListView(FormView, MongonautViewMixin):
+class DocumentListView(MongonautViewMixin, FormView):
     """ :args: <app_label> <document_name> 
     
         TODO - Make a generic document fetcher method
@@ -161,7 +162,7 @@ class DocumentListView(FormView, MongonautViewMixin):
             
         return self.form_invalid(form)                                    
 
-class DocumentDetailView(TemplateView, MongonautViewMixin):
+class DocumentDetailView(MongonautViewMixin, TemplateView):
     """ :args: <app_label> <document_name> <id> """
     template_name = "mongonaut/document_detail.html"
     
@@ -179,23 +180,25 @@ class DocumentDetailView(TemplateView, MongonautViewMixin):
         context['app_label'] = self.app_label  
         context['document_name'] = self.document_name
         context['keys'] = ['id',]
+        context['embedded_documents'] = []        
+        context['list_fields'] = []
         for key in sorted([x for x in self.document._fields.keys() if x != 'id']):
             # TODO - Figure out why this EmbeddedDocumentField and ListField breaks this view
             # Note - This is the challenge part, right? :)
             if isinstance(self.document._fields[key], EmbeddedDocumentField):            
+                context['embedded_documents'].append(key)
                 continue
             if isinstance(self.document._fields[key], ListField):                                
-                continue
+                context['list_fields'].append(key)
+                continue                
             context['keys'].append(key)
-            
-
         return context
  
 
-class DocumentDetailEditFormView(FormView, MongonautViewMixin):
+class DocumentEditFormView(MongonautViewMixin, FormView):
     """ :args: <app_label> <document_name> <id> """#
 
-    template_name = "mongonaut/document_detail_edit_form.html"
+    template_name = "mongonaut/document_edit_form.html"
     form_class = DocumentDetailForm
     success_url = '/'
     
@@ -204,7 +207,7 @@ class DocumentDetailEditFormView(FormView, MongonautViewMixin):
         return reverse('document_detail_edit_form', kwargs={'app_label':self.app_label,'document_name':self.document_name,'id':self.kwargs.get('id')})
     
     def get_context_data(self, **kwargs):
-        context = super(DocumentDetailEditFormView, self).get_context_data(**kwargs)
+        context = super(DocumentEditFormView, self).get_context_data(**kwargs)
         self.set_mongoadmin()        
         context = self.set_permissions_in_context(context)
         if not context['has_edit_permission']:
@@ -237,10 +240,7 @@ class DocumentDetailEditFormView(FormView, MongonautViewMixin):
             if self.form.is_valid():
                 for key, field in self.form.fields.items():                      
                     if 'readonly' in field.widget.attrs:
-                        # For _id
-                        # TODO - make the ones below work
-                        # For ListField - like 'field': <mongoengine.fields.StringField object at 0x101b51810>,                                
-                        # For EmbeddedDocumentField
+                        # For _id or things specified as such
                         continue       
                         
                     if isinstance(field.widget, DateTimeInput):
@@ -258,22 +258,22 @@ class DocumentDetailEditFormView(FormView, MongonautViewMixin):
                         
                     if isinstance(field.widget, widgets.Select):
                         # supporting reference fields!
-                        # TODO - support ListFields
                         value = field.mongofield.document_type.objects.get(id=self.request.POST[key])
-                        setattr(self.document, key, value)                        
+                        setattr(self.document, key, value)
                         continue
 
                     # for strings
                     setattr(self.document, key, self.request.POST[key])
+                    
                 self.document.save()
-                # TODO add message for save
+                messages.add_message(self.request, messages.INFO, 'Your changes have been saved.')
                 
         return self.form
         
-class DocumentDetailAddFormView(FormView, MongonautViewMixin):
+class DocumentAddFormView(MongonautViewMixin, FormView):
     """ :args: <app_label> <document_name> <id> """#
 
-    template_name = "mongonaut/document_detail_add_form.html"
+    template_name = "mongonaut/document_add_form.html"
     form_class = DocumentDetailForm
     success_url = '/'
 
@@ -282,11 +282,11 @@ class DocumentDetailAddFormView(FormView, MongonautViewMixin):
         return reverse('document_detail', kwargs={'app_label':self.app_label,'document_name':self.document_name,'id':str(self.document.id)})
 
     def get_context_data(self, **kwargs):
-        """ TODO - possibly inherit this from DocumentDetailEditFormView. This is same thing minus:
+        """ TODO - possibly inherit this from DocumentEditFormView. This is same thing minus:
             self.ident = self.kwargs.get('id')
             self.document = self.document_type.objects.get(id=self.ident)
         """
-        context = super(DocumentDetailAddFormView, self).get_context_data(**kwargs)
+        context = super(DocumentAddFormView, self).get_context_data(**kwargs)
         self.set_mongoadmin()        
         context = self.set_permissions_in_context(context)
         if not context['has_add_permission']:
@@ -310,10 +310,6 @@ class DocumentDetailAddFormView(FormView, MongonautViewMixin):
                 for key, field in self.form.fields.items():                      
                     if 'readonly' in field.widget.attrs:
                         # For _id
-                        # TODO - make the ones below work
-                        # for ReferenceField - like <class 'articles.models.User'> on Blog                        
-                        # For ListField - like 'field': <mongoengine.fields.StringField object at 0x101b51810>,                                
-                        # For EmbeddedDocumentField
                         continue       
 
                     if isinstance(field.widget, DateTimeInput):
@@ -327,15 +323,21 @@ class DocumentDetailAddFormView(FormView, MongonautViewMixin):
                         else:
                             setattr(self.document, key, False)
                         continue
+                        
+                    if isinstance(field.widget, widgets.Select):
+                        # supporting reference fields!
+                        value = field.mongofield.document_type.objects.get(id=self.request.POST[key])
+                        setattr(self.document, key, value)
+                        continue                        
 
                     # for strings
                     setattr(self.document, key, self.request.POST[key])
                 self.document.save()
-                # TODO add message for save
+                messages.add_message(self.request, messages.INFO, 'Your new document has been added and saved.')
 
         return self.form
 
-class DocumentDeleteView(TemplateView, DeletionMixin, MongonautViewMixin):
+class DocumentDeleteView(DeletionMixin, MongonautViewMixin, TemplateView):
     """ :args: <app_label> <document_name> <id> 
     
         TODO - implement a GET view for confirmation
@@ -345,7 +347,8 @@ class DocumentDeleteView(TemplateView, DeletionMixin, MongonautViewMixin):
     template_name = "mongonaut/document_delete.html"
     
     def get_success_url(self):
-        self.set_mongonaut_base()  
+        self.set_mongonaut_base()
+        messages.add_message(self.request, messages.INFO, 'Your document has been deleted.')
         return reverse('document_list', kwargs={'app_label':self.app_label,'document_name':self.document_name})
 
     def get_object(self):
@@ -353,9 +356,15 @@ class DocumentDeleteView(TemplateView, DeletionMixin, MongonautViewMixin):
         self.document_type = getattr(self.models, self.document_name)
         self.ident = self.kwargs.get('id')
         self.document = self.document_type.objects.get(id=self.ident)
-        return self.document        
+        return self.document   
+
+class ListFieldListView(MongonautViewMixin, FormView):
+    pass
+
+class EmbeddedDocumentView(MongonautViewMixin, DetailView):
+    pass
 
 
-class EmbeddedDocumentDetailView(DetailView, MongonautViewMixin):
+class EmbeddedDocumentDetailView(MongonautViewMixin, DetailView):
     """ :args: <app_label> <document_name> <id> <???> """
     template_name = "mongonaut/embedded_document_detail.html"
\ No newline at end of file
